@@ -1,6 +1,7 @@
 from .build import BuildCommand
 from .check import CheckCommand
 from .command import Command
+from .ppa import PPACommand
 from .root import RootCommand
 from .s3_repo import S3RepoCommand
 from .source import SourceCommand
@@ -12,4 +13,5 @@ __all__ = [
     "S3RepoCommand",
     "BuildCommand",
     "CheckCommand",
+    "PPACommand",
 ]
