@@ -13,9 +13,11 @@ class RootCommand(Command):
     """
 
     def __init__(self):
+        super().__init__()
         self.parser = EnvArgumentParser(
             prog="debutizer",
             description="A tool for managing APT packages",
+            usage=_USAGE,
         )
 
         self.parser.add_argument("command", nargs="?", help="The command to run")
@@ -34,3 +36,14 @@ class RootCommand(Command):
             command.run()
         else:
             raise CommandError(f"Unknown command: {args.command}")
+
+
+_USAGE = """debutizer <command> [<args>]
+
+Commands:
+  source     Makes source packages
+  build      Makes source and binary packages
+  check      Checks for system dependencies
+  s3-repo    Manages APT repositories backed by S3
+  ppa        Manages Ubuntu PPAs
+"""
