@@ -10,9 +10,11 @@ from .upload import UploadCommand
 
 class S3RepoCommand(Command):
     def __init__(self):
+        super().__init__()
         self.parser = EnvArgumentParser(
             prog="debutizer s3-repo",
             description="Manages repositories backed by an S3-compatible bucket",
+            usage=_USAGE,
         )
 
         self.parser.add_argument("command", nargs="?", help="The command to run")
@@ -23,8 +25,15 @@ class S3RepoCommand(Command):
     def behavior(self, args: argparse.Namespace) -> None:
         if args.command is None:
             self.parser.print_usage()
-        elif args.command in S3RepoCommand.subcommands:
-            command = S3RepoCommand.subcommands[args.command]
+        elif args.command in self.subcommands:
+            command = self.subcommands[args.command]
             command.run()
         else:
             raise CommandError(f"Unknown subcommand: {args.command}")
+
+
+_USAGE = """debutizer s3-repo <command> [<args>]
+
+Commands:
+  upload    Uploads packages to S3
+"""
